@@ -77,7 +77,7 @@ pred_segs <- function(model, x) {
 }
 
 
-#' Solve as piecewise linear problem.
+#' Solve as piecewise linear problem, numeric target.
 #'
 #' Return a vector of length y that is a piecewise function of x.
 #' This vector is picked as close to
@@ -106,6 +106,11 @@ solve_piecewise <- function(varName, x, y, w = NULL) {
     if(is.null(w)) {
       w <- numeric(n) + 1
     }
+    xorig <- x
+    order <- order(x)
+    x <- x[order]
+    y <- y[order]
+    w <- w[order]
     if(n<=20) {
       # too small, 1 or 2 segments
       k <- 2
@@ -131,7 +136,7 @@ solve_piecewise <- function(varName, x, y, w = NULL) {
       # print(k)
     }
     model <- fit_segments(x, y, k=k, w=w)
-    estimate <- pred_segs(model, x)
+    estimate <- pred_segs(model, xorig)
     approx_table <- data.frame(predXs = sort(unique(c(min(x), model$xs, max(x)))))
     approx_table$predYs <- pred_segs(model, approx_table$predXs)
     attr(estimate, "approx_table") <- approx_table
@@ -141,3 +146,26 @@ solve_piecewise <- function(varName, x, y, w = NULL) {
   error = function(e) { return(NULL) })
 }
 
+
+#' Solve as piecewise logit problem, categorical target.
+#'
+#' Return a vector of length y that is a piecewise function of x.
+#' This vector is picked as close to
+#' y (by square-distance) as possible for a set of x-only determined
+#' cut-points.  Cross-validates for a good number of segments.
+#'
+#' @param varName character, name of variable
+#' @param x numeric input (not empty, no NAs). 
+#' @param y numeric or castable to such (same length as x no NAs), output to match
+#' @param w numeric positive, same length as x (weights, can be NULL)
+#' @return segmented y prediction
+#'
+#'
+#' @export
+#' 
+solve_piecewisec <- function(varName, x, y, w = NULL) {
+  v <- solve_piecewise(varName = varName, 
+                     x = x, y = y , w = w)
+  # don't copy over approx table as we are piecewise logit, not piecewise linear.
+  .logit(v) - .logit(.wmean(y, w))
+}
